package com.ruoyi.system.service.impl.projectV2;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.projectV2.ZsyzJzqkTsMapper;
import com.ruoyi.system.domain.projectV2.ZsyzJzqkTs;
import com.ruoyi.system.service.projectV2.IZsyzJzqkTsService;

/**
 * 招商引资_进展情况_提示(当承接地已承接，但15天未填写签约信息的记录信息，前端给出提示框)Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-03-06
 */
@Service
public class ZsyzJzqkTsServiceImpl implements IZsyzJzqkTsService 
{
    @Autowired
    private ZsyzJzqkTsMapper zsyzJzqkTsMapper;

    /**
     * 查询招商引资_进展情况_提示(当承接地已承接，但15天未填写签约信息的记录信息，前端给出提示框)
     * 
     * @param id 招商引资_进展情况_提示(当承接地已承接，但15天未填写签约信息的记录信息，前端给出提示框)主键
     * @return 招商引资_进展情况_提示(当承接地已承接，但15天未填写签约信息的记录信息，前端给出提示框)
     */
    @Override
    public ZsyzJzqkTs selectZsyzJzqkTsById(Long id)
    {
        return zsyzJzqkTsMapper.selectZsyzJzqkTsById(id);
    }

    /**
     * 查询招商引资_进展情况_提示(当承接地已承接，但15天未填写签约信息的记录信息，前端给出提示框)列表
     * 
     * @param zsyzJzqkTs 招商引资_进展情况_提示(当承接地已承接，但15天未填写签约信息的记录信息，前端给出提示框)
     * @return 招商引资_进展情况_提示(当承接地已承接，但15天未填写签约信息的记录信息，前端给出提示框)
     */
    @Override
    public List<ZsyzJzqkTs> selectZsyzJzqkTsList(ZsyzJzqkTs zsyzJzqkTs)
    {
        return zsyzJzqkTsMapper.selectZsyzJzqkTsList(zsyzJzqkTs);
    }

    /**
     * 新增招商引资_进展情况_提示(当承接地已承接，但15天未填写签约信息的记录信息，前端给出提示框)
     * 
     * @param zsyzJzqkTs 招商引资_进展情况_提示(当承接地已承接，但15天未填写签约信息的记录信息，前端给出提示框)
     * @return 结果
     */
    @Override
    public int insertZsyzJzqkTs(ZsyzJzqkTs zsyzJzqkTs)
    {
        zsyzJzqkTs.setCreateTime(DateUtils.getNowDate());
        return zsyzJzqkTsMapper.insertZsyzJzqkTs(zsyzJzqkTs);
    }

    /**
     * 修改招商引资_进展情况_提示(当承接地已承接，但15天未填写签约信息的记录信息，前端给出提示框)
     * 
     * @param zsyzJzqkTs 招商引资_进展情况_提示(当承接地已承接，但15天未填写签约信息的记录信息，前端给出提示框)
     * @return 结果
     */
    @Override
    public int updateZsyzJzqkTs(ZsyzJzqkTs zsyzJzqkTs)
    {
        zsyzJzqkTs.setUpdateTime(DateUtils.getNowDate());
        return zsyzJzqkTsMapper.updateZsyzJzqkTs(zsyzJzqkTs);
    }

    /**
     * 批量删除招商引资_进展情况_提示(当承接地已承接，但15天未填写签约信息的记录信息，前端给出提示框)
     * 
     * @param ids 需要删除的招商引资_进展情况_提示(当承接地已承接，但15天未填写签约信息的记录信息，前端给出提示框)主键
     * @return 结果
     */
    @Override
    public int deleteZsyzJzqkTsByIds(Long[] ids)
    {
        return zsyzJzqkTsMapper.deleteZsyzJzqkTsByIds(ids);
    }

    /**
     * 删除招商引资_进展情况_提示(当承接地已承接，但15天未填写签约信息的记录信息，前端给出提示框)信息
     * 
     * @param id 招商引资_进展情况_提示(当承接地已承接，但15天未填写签约信息的记录信息，前端给出提示框)主键
     * @return 结果
     */
    @Override
    public int deleteZsyzJzqkTsById(Long id)
    {
        return zsyzJzqkTsMapper.deleteZsyzJzqkTsById(id);
    }
}
